@@ -448,6 +448,7 @@ def bench_param_server(c, s, *workers):
     print(format_time(end - start))
 
 
+@pytest.mark.xfail(reason='unknown')
 @gen_cluster(client=True)
 def test_compute(c, s, a, b):
 
@@ -469,8 +470,35 @@ def test_compute(c, s, a, b):
     assert result == 0 + 1 + 2 + 3 + 4
 
     start = time()
-    while a.data or b.data or a.actors or b.actors:
+    while a.data or b.data:
         yield gen.sleep(0.01)
+        assert time() < start + 5
+
+
+def test_compute_sync(client):
+    @dask.delayed
+    def f(n, counter):
+        assert isinstance(counter, Actor), type(counter)
+        for i in range(n):
+            counter.increment().result()
+
+    @dask.delayed
+    def check(counter, blanks):
+        return counter.n
+
+    counter = dask.delayed(Counter)()
+    values = [f(i, counter) for i in range(5)]
+    final = check(counter, values)
+
+    result = final.compute(actors=counter)
+    assert result == 0 + 1 + 2 + 3 + 4
+
+    def check(dask_worker):
+        return len(dask_worker.data) + len(dask_worker.actors)
+
+    start = time()
+    while any(client.run(check).values()):
+        sleep(0.01)
         assert time() < start + 2
 
 
