@@ -233,6 +233,45 @@ def All(args, quiet_exceptions=()):
     raise gen.Return(results)
 
 
+@gen.coroutine
+def Any(args, quiet_exceptions=()):
+    """ Wait on many tasks at the same time and return when any is finished
+
+    Err once any of the tasks err.
+
+    Parameters
+    ----------
+    args: futures to wait for
+    quiet_exceptions: tuple, Exception
+        Exception types to avoid logging if they fail
+    """
+    tasks = gen.WaitIterator(*args)
+    results = [None for _ in args]
+    while not tasks.done():
+        try:
+            result = yield tasks.next()
+        except Exception:
+            @gen.coroutine
+            def quiet():
+                """ Watch unfinished tasks
+
+                Otherwise if they err they get logged in a way that is hard to
+                control.  They need some other task to watch them so that they
+                are not orphaned
+                """
+                for task in list(tasks._unfinished):
+                    try:
+                        yield task
+                    except quiet_exceptions:
+                        pass
+            quiet()
+            raise
+
+        results[tasks.current_index] = result
+        break
+    raise gen.Return(results)
+
+
 def sync(loop, func, *args, **kwargs):
     """
     Run coroutine in loop running in separate thread.
@@ -241,6 +280,11 @@ def sync(loop, func, *args, **kwargs):
     if PollIOLoop and ((isinstance(loop, PollIOLoop) and getattr(loop, '_closing', False)) or
             (hasattr(loop, 'asyncio_loop') and loop.asyncio_loop._closed)):
         raise RuntimeError("IOLoop is closed")
+    try:
+        if loop.asyncio_loop.is_closed():  # tornado 6
+            raise RuntimeError("IOLoop is closed")
+    except AttributeError:
+        pass
 
     timeout = kwargs.pop('callback_timeout', None)
 
@@ -1425,3 +1469,12 @@ def iscoroutinefunction(f):
     if sys.version_info >= (3, 5) and inspect.iscoroutinefunction(f):
         return True
     return False
+
+
+@contextmanager
+def warn_on_duration(duration, msg):
+    start = time()
+    yield
+    stop = time()
+    if stop - start > parse_timedelta(duration):
+        warnings.warn(msg, stacklevel=2)
