@@ -7,6 +7,7 @@ import random
 from tornado import gen
 from tornado.gen import Return
 
+from dask.optimization import SubgraphCallable
 from toolz import merge, concat, groupby, drop
 
 from .core import rpc
@@ -90,10 +91,12 @@ class WrappedKey(object):
     only be accessed in a certain way.  Schedulers may have particular needs
     that can only be addressed by additional metadata.
     """
-
     def __init__(self, key):
         self.key = key
 
+    def __repr__(self):
+        return "%s('%s')" % (type(self).__name__, self.key)
+
 
 _round_robin_counter = [0]
 
@@ -144,7 +147,7 @@ collection_types = (tuple, list, set, frozenset)
 def unpack_remotedata(o, byte_keys=False, myset=None):
     """ Unpack WrappedKey objects from collection
 
-    Returns original collection and set of all found keys
+    Returns original collection and set of all found WrappedKey objects
 
     Examples
     --------
@@ -154,19 +157,19 @@ def unpack_remotedata(o, byte_keys=False, myset=None):
     >>> unpack_remotedata(())
     ((), set())
     >>> unpack_remotedata(rd)
-    ('mykey', {'mykey'})
+    ('mykey', {WrappedKey('mykey')})
     >>> unpack_remotedata([1, rd])
-    ([1, 'mykey'], {'mykey'})
+    ([1, 'mykey'], {WrappedKey('mykey')})
     >>> unpack_remotedata({1: rd})
-    ({1: 'mykey'}, {'mykey'})
+    ({1: 'mykey'}, {WrappedKey('mykey')})
     >>> unpack_remotedata({1: [rd]})
-    ({1: ['mykey']}, {'mykey'})
+    ({1: ['mykey']}, {WrappedKey('mykey')})
 
     Use the ``byte_keys=True`` keyword to force string keys
 
     >>> rd = WrappedKey(('x', 1))
     >>> unpack_remotedata(rd, byte_keys=True)
-    ("('x', 1)", {"('x', 1)"})
+    ("('x', 1)", {WrappedKey('('x', 1)')})
     """
     if myset is None:
         myset = set()
@@ -175,11 +178,30 @@ def unpack_remotedata(o, byte_keys=False, myset=None):
 
     typ = type(o)
 
+    if typ is tuple:
+        if not o:
+            return o
+        if type(o[0]) is SubgraphCallable:
+            sc = o[0]
+            futures = set()
+            dsk = {k: unpack_remotedata(v, byte_keys, futures)
+                   for k, v in sc.dsk.items()}
+            args = tuple(unpack_remotedata(i, byte_keys, futures) for i in o[1:])
+            if futures:
+                myset.update(futures)
+                futures = (tuple(tokey(f.key) for f in futures)
+                           if byte_keys else tuple(f.key for f in futures))
+                inkeys = sc.inkeys + futures
+                return (SubgraphCallable(dsk, sc.outkey, inkeys, sc.name),) + args + futures
+            else:
+                return o
+        else:
+            return tuple(unpack_remotedata(item, byte_keys, myset) for item in o)
     if typ in collection_types:
         if not o:
             return o
         outs = [unpack_remotedata(item, byte_keys, myset) for item in o]
-        return type(o)(outs)
+        return typ(outs)
     elif typ is dict:
         if o:
             values = [unpack_remotedata(v, byte_keys, myset) for v in o.values()]
@@ -190,7 +212,7 @@ def unpack_remotedata(o, byte_keys=False, myset=None):
         k = o.key
         if byte_keys:
             k = tokey(k)
-        myset.add(k)
+        myset.add(o)
         return k
     else:
         return o
